@@ -10,6 +10,8 @@
 #include <RcppEigen.h>
 #else
 #include <Eigen/Core>
+#include <Eigen/Dense>
+#include <Eigen/LU>
 #endif
 
 #ifdef __clang__
@@ -21,6 +23,7 @@
 //glmmrbase version 
 #define GLMMR10
 #define GLMMR11
+#define GLMMR12
 
 // includes
 
@@ -31,10 +34,10 @@
 #include <algorithm>
 #include <cmath>
 #include <cctype>
-#include <SparseChol.h>
 #include <set>
+#include <map>
 #include <unordered_map>
-#include <random>
+#include <SparseChol.h>
 
 
 using namespace Eigen;
