@@ -1399,6 +1399,17 @@ SEXP Model__D(SEXP xp, int type = 0){
   return wrap(std::get<Eigen::MatrixXd>(S));
 }
 
+// [[Rcpp::export]]
+SEXP Model__log_re(SEXP xp, int type = 0){
+  glmmrType model(xp,static_cast<Type>(type));
+  auto functor = overloaded {
+    [](int) {  return returnType(0);}, 
+    [](auto ptr){return returnType(ptr->model.covariance.all_log_re());}
+  };
+  auto S = std::visit(functor,model.ptr);
+  return wrap(std::get<bool>(S));
+}
+
 // [[Rcpp::export]]
 SEXP Model__D_chol(SEXP xp, int type = 0){
   glmmrType model(xp,static_cast<Type>(type));
@@ -2202,8 +2213,7 @@ SEXP hessian_from_formula(SEXP form_,
                                       colnames,
                                       calc.data);
  (void)outparse;
- std::reverse(calc.instructions.begin(),calc.instructions.end());
- std::reverse(calc.indexes.begin(),calc.indexes.end());
+ calc.reverse_vectors();
  if(calc.parameter_names.size() != parameters.size())throw std::runtime_error("Wrong number of parameters");
  calc.parameters = parameters;
  VectorMatrix result = calc.jacobian_and_hessian();
